@@ -17,14 +17,7 @@ sub execute {
 
     if ( $self->is_valid ) {
         $doc->convert_to_collection;
-        local $@;
-        eval {
-            $self->repository->retrieve_all( %{ $self } );
-            1;
-        } or do {
-            my $e = $@;
-            $self->_handle_error($e);
-        };
+        $self->repository->retrieve_all( %{ $self } );
     }
 
     return $self->response();
@@ -45,7 +38,7 @@ PONAPI::DAO::Request::RetrieveAll - PONAPI - Perl implementation of {JSON:API} (
 
 =head1 VERSION
 
-version 0.001001
+version 0.001002
 
 =head1 AUTHOR
 
