@@ -19,18 +19,10 @@ sub execute {
     my $self = shift;
 
     if ( $self->is_valid ) {
-        local $@;
-        eval {
-            my @ret = $self->repository->update( %{ $self } );
+        my @ret = $self->repository->update( %{ $self } );
 
-            $self->_add_success_meta(@ret)
-                if $self->_verify_update_response(@ret);
-
-            1;
-        } or do {
-            my $e = $@;
-            $self->_handle_error($e);
-        };
+        $self->_add_success_meta(@ret)
+            if $self->_verify_update_response(@ret);
     }
 
     return $self->response();
@@ -51,7 +43,7 @@ PONAPI::DAO::Request::Update - PONAPI - Perl implementation of {JSON:API} (http:
 
 =head1 VERSION
 
-version 0.001001
+version 0.001002
 
 =head1 AUTHOR
 
